@@ -1,5 +1,6 @@
 from kdp_connector.configuration.configurationUtil import ConfigurationUtil
 from kdp_connector.configuration.authenticationUtil import AuthenticationUtil
+from kdp_connector.configuration.keycloak_authentication import KeycloakAuthentication
 from kdp_connector.connectors.batch_write import WriteApi
 from kdp_connector.connectors.ingest_job_api import IngestJobApi
 from kdp_connector.connectors.read import ReadApi
@@ -76,8 +77,33 @@ class KdpConn(object):
         auth_response = auth_util.create_proxy_authentication_token(config, first_name, workspace_id, strategy)
         return auth_response
 
+    def create_keycloak_authentication_token(self, realm: str, client_id: str, client_secret: str, username: str, password: str, workspace_id: str, host: str, verify_ssl: True) -> object:
+          """This method will be used to authenticate to Koverse via Keycloak
+
+              :param str realm: Keycloak URL including host, realm, broker, etc.
+              :param str client_id: Keycloak Client ID
+              :param str client_secret: Keycloak Client Password
+              :param str email: Email for KeyCloak authentication, optional, requires password
+              :param str password: Password for Keycloak authentication, optional, requires email
+              :param str workspace_id: Koverse Workspace ID
+
+              :returns: Koverse Authentication token
+
+              :rtype: AuthenticationDetails
+          """
+
+          keycloakAuth = KeycloakAuthentication()
+          values=f'Configuration values realm:{realm}, client_id:{client_id}, client_secret:{client_secret}, username:{username}, password: {password}, host: {host}, verify_ssl: {verify_ssl}'
+          print(values)
+          keycloakAuth.set_configuration(realm=realm, client_id=client_id, client_secret=client_secret, username=username, password=password, host=host, verify_ssl=verify_ssl)
+          print('Set keycloak configuration')
+          auth_util = AuthenticationUtil()
+          config = self.create_configuration('')
+          print('Calling to get koverse token from keycloak login')
+          return auth_util.get_koverse_token_from_keycloak_login(config=config, keycloak=keycloakAuth, workspace_id=workspace_id)
 
 
+    # , kc_username: str, kc_password: str,
     # WRITE
     def batch_write(self, dataframe, dataset_id: str, jwt: str, batch_size: int = 100, is_async: bool = True):
         """This method will be used to write batches of data to KDP
